<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-archiviste?lang_cible=pt_br
// ** ne pas modifier le fichier **

return [
	// A
	'archiviste_description' => 'Permite comprimir ou expandir arquivos Zip, Tar, ...',
	'archiviste_nom' => 'Arquivista',
	'archiviste_slogan' => 'Gerenciar arquivos compactados'
];
